@@ -191,7 +191,7 @@ enum LYX_CODE {
 };
 
 void SetZoom(char new_zoom);
-char GetZoom();
+//char GetZoom(); // seems to be unused. (Lgb)
 
 /* load a style-file, still VERY dump */ 
 void LyXSetStyle(const char *path);
@@ -206,22 +206,14 @@ char* date();
 inline
 int Maximum(int a, int b)
 {
-#ifdef __GNUG__
-	return (a >? b);
-#else
 	return ((a>b) ? a : b);
-#endif
 }
 
 
 inline
 int Minimum(int a, int b)
 {
-#ifdef __GNUG__
-	return (a <? b);
-#else
 	return ((a<b) ? a : b);
-#endif
 }
 
 
