@@ -35,29 +35,36 @@ static const char* lyx_sty[] = {
 //  "  {\\medskip\\noindent\\rule{\\columnwidth}{#1}\\linebreak\\medskip}",
 //  "}",
 
-  "\\newenvironment{lyxsectionbibliography}",
-  "{",
-  "\\section*{\\refname}",
-  "\\@mkboth{\\uppercase{\\refname}}{\\uppercase{\\refname}}",
-  "\\begin{list}{}{",
-  "\\itemindent-\\leftmargin",
-  "\\labelsep 0pt",
-  "\\renewcommand{\\makelabel}{}",
-  "}",
-  "}",
-  "{\\end{list}}",
+//   "\\newenvironment{lyxsectionbibliography}",
+//   "{",
+//   "\\section*{\\refname}",
+//   "\\@mkboth{\\uppercase{\\refname}}{\\uppercase{\\refname}}",
+//   "\\begin{list}{}{",
+//   "\\itemindent-\\leftmargin",
+//   "\\labelsep 0pt",
+//   "\\renewcommand{\\makelabel}{}",
+//   "}",
+//   "}",
+//   "{\\end{list}}",
 
-  "\\newenvironment{lyxchapterbibliography}",
+  "\\newenvironment{lyxbibliography}",
   "{",
-  "\\chapter*{\\bibname}",
-  "\\@mkboth{\\uppercase{\\bibname}}{\\uppercase{\\bibname}}",
-  "\\begin{list}{}{",
-  "\\itemindent-\\leftmargin",
-  "\\labelsep 0pt",
-  "\\renewcommand{\\makelabel}{}",
+  "\\begin{thebibliography}{99}" // this {99} must do for now (Lgb)
   "}",
-  "}",
-  "{\\end{list}}",
+  "{\\end{thebibliography}}",
+
+//   "\\newenvironment{lyxchapterbibliography}",
+//   "{",
+//   "\\chapter*{\\bibname}",
+//   "\\@mkboth{\\uppercase{\\bibname}}{\\uppercase{\\bibname}}",
+//   "\\begin{list}{}{",
+//   "\\itemindent-\\leftmargin",
+//   "\\labelsep 0pt",
+//   "\\renewcommand{\\makelabel}{}",
+//   "}",
+//   "}",
+//   "{\\end{list}}",
+  
   "\\def\\lxq{\"}",
   "\\newenvironment{lyxcode}",
   "{\\list{}{",
