@@ -206,8 +206,8 @@ public:
 	inline bool IsKomma(int pos){
 		return IsKommaChar(GetChar(pos));
 	}
-	inline bool IsWordSeparator(int pos){
-		return IsWordSeparatorChar(GetChar(pos));
+	inline bool IsLetter(int pos){
+		return IsLetterChar((unsigned char) GetChar(pos));
 	}
 	
 	inline int ClearParagraph(){
