@@ -24,12 +24,13 @@ extern const char* string_pagestyle[];
 class LyXTextParameters {
 private:
 	void readFileOld();
-	void readLyXformat2();
+	//void readLyXformat2();
 	void linuxDocOnePar(FILE*, LyXParagraph*&,LyXParagraph*&, int is_init);
 public:  				  
         LyXTextParameters();
         LyXTextParameters(LyXTextParameters &p);
 	~LyXTextParameters();
+	void readLyXformat2(LyXParagraph *par = NULL);
 	void LinuxDocError(LyXParagraph *par, int pos, const char *message);
 	int LinuxDocTag(const char *layout);
 	void push_tag(FILE *file, const char *tag, int& pos, char stack[5][3]);
