@@ -241,6 +241,8 @@ public:
   void CursorRight();
   void CursorLeftOneWord();
   void CursorRightOneWord();
+  void CursorUpParagraph();
+  void CursorDownParagraph();
   void CursorHome();
   void CursorEnd();
   void CursorTab();
