@@ -114,6 +114,11 @@ class LyXTable  {
   };
 
    int rows, columns;
+
+   int numberofcells;
+   int* rowofcell;
+   int* columnofcell;
+   void set_row_column_number_info();
    
    char* alignment;
    char* top_line;
