@@ -52,16 +52,9 @@
 			|| c==LYX_META_PROTECTED_SEPARATOR
 			);
 	}
-	inline bool IsWordSeparatorChar(char c) {
-		return (IsKommaChar(c)
-			|| IsSeparatorChar(c)
-			|| c==LYX_META_NEWLINE
-			|| c==LYX_META_FOOTNOTE
-			|| c==LYX_META_MARGIN
-			|| c==LYX_META_FIG
-			|| c==LYX_META_TAB
-			|| c==LYX_META_HFILL
-			|| c==LYX_META_INSET
-			);
+	inline bool IsLetterChar(unsigned char c) {
+		return ((c>='A' && c<='Z')
+			|| (c>='a' && c<='z')
+			|| (c>=192)); // in iso-8859-x these are accented chars
 	}
 #endif
